pub fn path_has_segment(path: &Path, marker: &str) -> boolExpand description
true if any segment of path is exactly marker.
Used to catch a module marker (fs, net, Command, …) appearing
anywhere in a call path, regardless of how much of the path precedes or
follows it.